complete -c dfrs -n "__fish_use_subcommand" -l color -d 'Bypass tty detection for colors' -r -f -a "auto always never"
complete -c dfrs -n "__fish_use_subcommand" -l mounts -d 'File to get mount information from'
complete -c dfrs -n "__fish_use_subcommand" -l columns -d 'Display columns as comma separated list' -r -f -a "filesystem type bar used used_percentage available available_percentage capacity mounted_on"
complete -c dfrs -n "__fish_use_subcommand" -s a -d 'Show more, use twice to show all'
complete -c dfrs -n "__fish_use_subcommand" -l more -d 'Show more'
complete -c dfrs -n "__fish_use_subcommand" -l all -d 'Show all'
complete -c dfrs -n "__fish_use_subcommand" -s c -d 'Bypass tty detection and always show colors'
complete -c dfrs -n "__fish_use_subcommand" -s i -l inodes -d 'Show inode instead of block usage'
complete -c dfrs -n "__fish_use_subcommand" -s h -l human-readable -d 'Print sizes in powers of 1024 (e.g., 1023M)'
complete -c dfrs -n "__fish_use_subcommand" -s H -l si -d 'Print sizes in powers of 1000 (e.g., 1.1G)'
complete -c dfrs -n "__fish_use_subcommand" -l total -d 'Produce and show a grand total'
complete -c dfrs -n "__fish_use_subcommand" -s l -l local -d 'Limit listing to local file systems'
complete -c dfrs -n "__fish_use_subcommand" -l no-aliases -d 'Do not resolve file system shorthand aliases (e.g., LVM)'
complete -c dfrs -n "__fish_use_subcommand" -s v -d 'Verbose logging'
complete -c dfrs -n "__fish_use_subcommand" -l help -d 'Prints help information'
complete -c dfrs -n "__fish_use_subcommand" -s V -l version -d 'Prints version information'
complete -c dfrs -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c dfrs -n "__fish_use_subcommand" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c dfrs -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Prints help information'
complete -c dfrs -n "__fish_seen_subcommand_from completions" -s V -l version -d 'Prints version information'
complete -c dfrs -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c dfrs -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
